@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentStats.pm
 # Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentStats.pm,v 1.18 2006/10/06 14:41:43 tr Exp $
+# $Id: AgentStats.pm,v 1.21 2006/11/15 08:25:09 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,7 +17,7 @@ use Kernel::System::CSV;
 use Kernel::System::PDF;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.18 $';
+$VERSION = '$Revision: 1.21 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -253,7 +253,6 @@ sub Run {
             );
         }
 
-
         # get static attributes
         if ($Stat->{StatType} eq 'static') {
             # load static modul
@@ -733,7 +732,19 @@ sub Run {
         # save EditSpecification
         if ($Param{Home} eq 'EditSpecification') {
             # save string
-            foreach (qw(Title Description Object File SumRow SumCol Cache StatType Valid)) {
+            foreach (qw(Title Description)) {
+                if (defined ($Self->{ParamObject}->GetParam(Param => $_))) {
+                    my $Param = $Self->{ParamObject}->GetParam(Param => $_);
+                    $Data{$_} = $Param;
+                    $Data{$_} =~ s/^\s+//;
+                    $Data{$_} =~ s/\s+$//;
+                }
+                else {
+                    $Data{$_} = '';
+                }
+            }
+
+            foreach (qw(Object File SumRow SumCol Cache StatType Valid)) {
                 if (defined ($Self->{ParamObject}->GetParam(Param => $_))) {
                     my $Param = $Self->{ParamObject}->GetParam(Param => $_);
                     $Data{$_} = $Param;
@@ -742,6 +753,7 @@ sub Run {
                     $Data{$_} = '';
                 }
             }
+
             if($Data{StatType} eq '') {
                 $Data{File}         = '';
                 $Data{Object}       = '';
@@ -851,7 +863,6 @@ sub Run {
                                     }
                                 }
 
-
                                 $Data{UseAsXvalue}[0]{"Time$Limit"} =
                                     sprintf("%04d-%02d-%02d %02d:%02d:%02d",
                                     $Time{$Limit . "Year"},
@@ -1089,7 +1100,7 @@ sub Run {
                     Name => 'Selection',
                 );
                 # need a radiobutton if dynamic and static stats available
-                if ($#StaticFilesArray > 0) {
+                if ($StaticFilesArray[0]) {
                     $Self->{LayoutObject}->Block(
                         Name => 'RadioButton',
                         Data => {
@@ -1104,7 +1115,8 @@ sub Run {
                         Data => {
                             Name      => 'Dynamic-Object',
                             StateType => 'dynamic',
-                        }                    );
+                        }
+                    );
                 }
                 # need a dropdown menue if more dynamic objects available
                 if ($#DynamicFilesArray > 1) {
@@ -1132,7 +1144,7 @@ sub Run {
                 }
             }
             # build the static stats selection if one or more static stats available
-            if (@StaticFilesArray && $#StaticFilesArray > 0) {
+            if (@StaticFilesArray) {
                 $Self->{LayoutObject}->Block(
                     Name => 'Selection',
                 );
@@ -1156,7 +1168,7 @@ sub Run {
                         }                    );
                 }
                 # more static stats available? than make a SelectField
-                if ($#StaticFilesArray > 1) {
+                if ($#StaticFilesArray > 0) {
                     $Frontend{SelectField} = $Self->{LayoutObject}->OptionStrgHashRef(
                         Data     => $StaticFiles,
                         Name     => 'File',
@@ -1311,8 +1323,6 @@ sub Run {
                  $ObjectAttribute->{Block} = 'MultiSelectField';
             }
 
-
-
             if ($ObjectAttribute->{Block} eq 'MultiSelectField') {
                 $BlockData{SelectField} = $Self->{LayoutObject}->OptionStrgHashRef(
                     Data                => $ObjectAttribute->{Values},
@@ -1484,7 +1494,6 @@ sub Run {
                     $ObjectAttribute->{Block} = 'TimeExtended';
                 }
 
-
                 my %TimeData = _Timeoutput($Self, %{$ObjectAttribute});
                 %BlockData = (%BlockData, %TimeData);
             }
@@ -1889,7 +1898,7 @@ sub Run {
         }
         # Gernerate Filename
         my $Filename = $Self->{StatsObject}->StringAndTimestamp2Filename(
-            String => $Title . " Created",
+            String => $Stat->{Title} . " Created",
         );
 
         # csv output
