@@ -2,7 +2,7 @@
 # Kernel/System/Web/InterfaceCustomer.pm - the customer interface file (incl. auth)
 # Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
 # --
-# $Id: InterfaceCustomer.pm,v 1.12 2006/10/05 01:46:33 martin Exp $
+# $Id: InterfaceCustomer.pm,v 1.16 2006/11/09 16:48:30 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,12 +14,10 @@ package Kernel::System::Web::InterfaceCustomer;
 use strict;
 
 use vars qw($VERSION @INC);
-$VERSION = '$Revision: 1.12 $';
+$VERSION = '$Revision: 1.16 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 # all framework needed modules
-# --
 use Kernel::Config;
 use Kernel::System::Log;
 use Kernel::System::Main;
@@ -72,9 +70,7 @@ sub new {
     # performance log
     $Self->{PerformanceLogStart} = time();
 
-    # --
     # create common framework objects 1/3
-    # --
     $Self->{ConfigObject} = Kernel::Config->new();
     $Self->{LogObject} = Kernel::System::Log->new(
         LogPrefix => $Self->{ConfigObject}->Get('CGILogPrefix'),
@@ -87,9 +83,8 @@ sub new {
         %{$Self},
         WebRequest => $Param{WebRequest} || 0,
     );
-    # --
+
     # debug info
-    # --
     if ($Self->{Debug}) {
         $Self->{LogObject}->Log(
             Priority => 'debug',
@@ -109,9 +104,8 @@ execute the object
 
 sub Run {
     my $Self = shift;
-    # --
+
     # get common framework params
-    # --
     my %Param = ();
     # get session id
     $Param{SessionName} = $Self->{ConfigObject}->Get('CustomerPanelSessionName') || 'CSID';
@@ -130,27 +124,23 @@ sub Run {
         $Param{$Key} = $Self->{ParamObject}->GetParam(Param => $Key)
           || $FramworkPrams->{$Key};
     }
-    # --
+
     # Check if the brwoser sends the SessionID cookie and set the SessionID-cookie
     # as SessionID! GET or POST SessionID have the lowest priority.
-    # --
     if ($Self->{ConfigObject}->Get('SessionUseCookie')) {
       $Param{SessionIDCookie} = $Self->{ParamObject}->GetCookie(Key => $Param{SessionName});
       if ($Param{SessionIDCookie}) {
         $Param{SessionID} = $Param{SessionIDCookie};
       }
     }
-    # --
+
     # create common framework objects 2/3
-    # --
     $Self->{LayoutObject} = Kernel::Output::HTML::Layout->new(
         %{$Self},
         Lang => $Param{Lang},
     );
 
-    # --
     # check common objects
-    # --
     $Self->{DBObject} = Kernel::System::DB->new(%{$Self});
     if (!$Self->{DBObject}) {
         print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
@@ -169,15 +159,13 @@ sub Run {
         print $Self->{LayoutObject}->CustomerFooter();
         exit (1);
     }
-    # --
+
     # create common framework objects 3/3
-    # --
     $Self->{UserObject} = Kernel::System::CustomerUser->new(%{$Self});
     $Self->{GroupObject} = Kernel::System::CustomerGroup->new(%{$Self});
     $Self->{SessionObject} = Kernel::System::AuthSession->new(%{$Self});
-    # --
+
     # application and add on application common objects
-    # --
     my %CommonObject = %{$Self->{ConfigObject}->Get('CustomerFrontend::CommonObject')};
     foreach my $Key (keys %CommonObject) {
         if ($Self->{MainObject}->Require($CommonObject{$Key})) {
@@ -191,18 +179,16 @@ sub Run {
             exit;
         }
     }
-    # --
+
     # get common application and add on application params
-    # --
     my %CommonObjectParam = %{$Self->{ConfigObject}->Get('CustomerFrontend::CommonParam')};
     foreach my $Key (keys %CommonObjectParam) {
         $Param{$Key} = $Self->{ParamObject}->GetParam(Param => $Key) || $CommonObjectParam{$Key};
     }
     # security check Action Param (replace non word chars)
     $Param{Action} =~ s/\W//g;
-    # --
+
     # check request type
-    # --
     if ($Param{Action} eq "Login") {
         # get params
         my $PostUser = $Self->{ParamObject}->GetParam(Param => 'User') || '';
@@ -246,6 +232,29 @@ sub Run {
                 UserLastRequest => $Self->{TimeObject}->SystemTime(),
                 UserType => 'Customer',
             );
+            # set time zone offset if TimeZoneFeature is active
+            if ($Self->{ConfigObject}->Get('TimeZoneUser') &&
+                $Self->{ConfigObject}->Get('TimeZoneUserBrowserAutoOffset') &&
+                    $Self->{LayoutObject}->{BrowserJavaScriptSupport}) {
+                my $TimeOffset = $Self->{ParamObject}->GetParam(Param => 'TimeOffset') || '';
+                if ($TimeOffset > 0) {
+                    $TimeOffset = '-'.($TimeOffset/60);
+                }
+                else {
+                    $TimeOffset = ($TimeOffset/60);
+                    $TimeOffset =~ s/-/+/;
+                }
+                $Self->{UserObject}->SetPreferences(
+                    UserID => $UserData{UserID},
+                    Key => 'UserTimeZone',
+                    Value => $TimeOffset,
+                );
+                $Self->{SessionObject}->UpdateSessionID(
+                    SessionID => $NewSessionID,
+                    Key => 'UserTimeZone',
+                    Value => $TimeOffset,
+                );
+            }
             # create a new LayoutObject with SessionIDCookie
             my $Expires = '+'.$Self->{ConfigObject}->Get('SessionMaxTime').'s';
             if (!$Self->{ConfigObject}->Get('SessionUseCookieAfterBrowserClose')) {
@@ -263,9 +272,8 @@ sub Run {
                 SessionName => $Param{SessionName},
                 %{$Self},
             );
-            # --
+
             # redirect with new session id and old params
-            # --
             # prepare old redirect URL -- do not redirect to Login or Logout (loop)!
             if ($Param{RequestedURL} =~ /Action=(Logout|Login)/) {
                 $Param{RequestedURL} = '';
@@ -297,9 +305,8 @@ sub Run {
             }
         }
     }
-    # --
+
     # Logout
-    # --
     elsif ($Param{Action} eq "Logout"){
         if ($Self->{SessionObject}->CheckSessionID(SessionID => $Param{SessionID})) {
             # get session data
@@ -338,12 +345,12 @@ sub Run {
             else {
                 print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Logout');
                 print $Self->{LayoutObject}->CustomerError(
-                  Message => 'Can`t remove SessionID',
-                  Comment => 'Please contact your admin!'
+                    Message => 'Can`t remove SessionID',
+                    Comment => 'Please contact your admin!'
                 );
                 $Self->{LogObject}->Log(
-            		Message => 'Can`t remove SessionID',
-            		Priority => 'error',
+                    Message => 'Can`t remove SessionID',
+                    Priority => 'error',
                 );
                 print $Self->{LayoutObject}->CustomerFooter();
             }
@@ -353,23 +360,22 @@ sub Run {
                 # redirect to alternate login
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
-        		 ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
-        		  "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
+                    ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
+                    "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show login screen
                 print $Self->{LayoutObject}->CustomerLogin(
-            		Title => 'Logout',
-            		Message => 'Invalid SessionID!',
-            		%Param,
+                    Title => 'Logout',
+                    Message => 'Invalid SessionID!',
+                    %Param,
                 );
             }
         }
     }
-    # --
+
     # CustomerLostPassword
-    # --
     elsif ($Param{Action} eq "CustomerLostPassword"){
         # check feature
         if (! $Self->{ConfigObject}->Get('CustomerPanelLostPassword')) {
@@ -423,9 +429,8 @@ sub Run {
             }
         }
     }
-    # --
+
     # create new customer account
-    # --
     elsif ($Param{Action} eq "CustomerCreateAccount"){
         # check feature
         if (! $Self->{ConfigObject}->Get('CustomerPanelCreateAccount')) {
@@ -521,9 +526,8 @@ sub Run {
             }
         }
     }
-    # --
+
     # show login site
-    # --
     elsif (!$Param{SessionID}) {
         # create AuthObject
         my $AuthObject = Kernel::System::CustomerAuth->new(%{$Self});
@@ -550,9 +554,8 @@ sub Run {
             );
         }
     }
-    # --
+
     # run modules if exists a version value
-    # --
     elsif ($Self->{MainObject}->Require("Kernel::Modules::$Param{Action}")) {
         # check session id
         if ( !$Self->{SessionObject}->CheckSessionID(SessionID => $Param{SessionID}) ) {
@@ -584,9 +587,8 @@ sub Run {
                 );
             }
         }
-        # --
+
         # run module
-        # --
         else {
             # get session data
             my %UserData = $Self->{SessionObject}->GetSessionIDData(
@@ -595,19 +597,19 @@ sub Run {
             # check needed data
             if (!$UserData{UserID} || !$UserData{UserLogin} || $UserData{UserType} ne 'Customer') {
                 if ($Self->{ConfigObject}->Get('CustomerPanelLoginURL')) {
-            		# redirect to alternate login
-            		print $Self->{LayoutObject}->Redirect(
-            			ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL')."?Reason=SystemError",
-            		);
+                    # redirect to alternate login
+                    print $Self->{LayoutObject}->Redirect(
+                        ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL')."?Reason=SystemError",
+                    );
                 }
                 else {
-            		# show login screen
-            		print $Self->{LayoutObject}->CustomerLogin(
-            			Title => 'Panic!',
-            			Message => 'Panic! Invalid Session!!!',
-            			%Param,
-            		);
-            		exit (0);
+                    # show login screen
+                    print $Self->{LayoutObject}->CustomerLogin(
+                        Title => 'Panic!',
+                        Message => 'Panic! Invalid Session!!!',
+                        %Param,
+                    );
+                    exit (0);
                 }
             }
             # create new LayoutObject with new '%Param' and '%UserData'
@@ -714,9 +716,8 @@ sub Run {
             }
         }
     }
-    # --
+
     # else print an error screen
-    # --
     else {
         # create new LayoutObject with '%Param'
         my %Data = $Self->{SessionObject}->GetSessionIDData(
@@ -732,21 +733,19 @@ sub Run {
         print $Self->{LayoutObject}->CustomerError();
         print $Self->{LayoutObject}->CustomerFooter();
     }
-    # --
+
     # debug info
-    # --
     if ($Self->{Debug}) {
         $Self->{LogObject}->Log(
             Priority => 'debug',
             Message => 'Global handle stopped.',
         );
     }
-    # --
     # db disconnect && undef %Param
-    # --
     $Self->{DBObject}->Disconnect();
     undef %Param;
 }
+
 1;
 
 =head1 TERMS AND CONDITIONS
@@ -761,6 +760,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.12 $ $Date: 2006/10/05 01:46:33 $
+$Revision: 1.16 $ $Date: 2006/11/09 16:48:30 $
 
 =cut
