@@ -2,7 +2,7 @@
 -- Update an existing OTRS database from 2.0 to 2.1
 -- Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
 -- --
--- $Id: DBUpdate-to-2.1.oracle.sql,v 1.5 2006/10/04 11:33:45 rk Exp $
+-- $Id: DBUpdate-to-2.1.oracle.sql,v 1.6 2006/10/20 14:02:12 rk Exp $
 -- --
 --
 -- usage: cat DBUpdate-to-2.1.oracle.sql | sqlplus "user/password"
@@ -149,5 +149,12 @@ ALTER TABLE faq_item CHANGE change_by changed_by NUMBER;
 ALTER TABLE faq_item CHANGE create_time created DATE;
 ALTER TABLE faq_item CHANGE change_time changed DATE;
 
+ALTER TABLE faq_attachment CHANGE create_by created_by NUMBER;
+ALTER TABLE faq_attachment CHANGE change_by changed_by NUMBER;
+ALTER TABLE faq_attachment CHANGE create_time created DATE;
+ALTER TABLE faq_attachment CHANGE change_time changed DATE;
+
+
+
 
 
